from typing import Optional, Dict, Tuple, Union
from imagine.remote.http_client import HttpClient
from imagine.utils.imports.dynamic import dynamic_import


class TestRequestClient(HttpClient):
    __base_url: str = "https://api.vyro.ai/v1/imagine/api"

    def post(
        self,
        endpoint: str,
        parameters: Dict[str, Union[int, float, str]],
        files: Optional[Dict[str, bytes]] = None,
        headers: Dict[str, str] = None,
    ) -> Tuple[int, bytes]:
        requests = dynamic_import("requests")
        if requests is None:
            return (1000, b"Module requests could not be loaded.")

        url = self.__base_url + endpoint

        response = requests.post(
            url, headers=headers, data=parameters, files=files, timeout=180
        )

        return (response.status_code, response.content)



from enum import Enum


class GenerationsStyle(Enum):
    """
    Enums for generation style_ids
    """

    STYLE_ANIME = 21
    STYLE_PORTRAIT = 26
    STYLE_IMAGINE_V1 = 27
    STYLE_IMAGINE_V3 = 28
    STYLE_REALISTIC = 29
    STYLE_IMAGINE_V4 = 30
    STYLE_IMAGINE_V4_CREATIVE = 31
    STYLE_IMAGINE_V4_1 = 32
    STYLE_IMAGINE_V5 = 33
    STYLE_DELIBERATE = 100
    STYLE_MAGIC_MIX = 101
    STYLE_DISNEY = 102
    STYLE_ABYSS_ORANGE_MIX = 103
    STYLE_LYRIEL = 104
    STYLE_RPG_4 = 105
    STYLE_REALISTIC_VISION = 110
    STYLE_DREAM_SHAPER = 111
    STYLE_REV_ANIMATED = 112
    STYLE_TOON_YOU = 113
    STYLE_UNREAL_ENGINE_5 = 114
    STYLE_EPIC_REALISM = 115
    STYLE_MEINA_MIX = 116
    STYLE_XX_MIX_9_REALISTIC = 117
    STYLE_3D_RENDERING_STYLE = 118
    STYLE_ABSOLUTE_REALITY_V1_6 = 119



from setuptools import setup
from setuptools import find_packages

setup(
    name="imaginesdk",
    version="1.0.0-beta03",
    description="Python client library for the Imagine API",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/Vyro-ai/imagine-sdk-python",
    author="Vyro",
    author_email="api.imagine@vyro.ai",
    license="MIT",
    package_dir={"": "src"},
    packages=find_packages("src"),
    python_requires=">=3.6",
    extras_require={
        "embeddings": [
            "numpy",
            "Pillow",
            "requests",
        ]
    },
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
    ],
)
